==> nextcloud-23.0.9.tgz: nextcloud/apps/dav/l10n/nl.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Agenda",
    "To-dos" : "Taken",
    "Personal" : "Persoonlijk",
    "{actor} created calendar {calendar}" : "{actor} creëerde agenda {calendar}",
    "You created calendar {calendar}" : "Jij creëerde agenda {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} verwijderde agenda {calendar}",
    "You deleted calendar {calendar}" : "Je verwijderde agenda {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} werkte agenda {calendar} bij",
    "You updated calendar {calendar}" : "Je werkte agenda {calendar} bij",
    "{actor} restored calendar {calendar}" : "{actor} herstelde agenda {calendar}",
    "You restored calendar {calendar}" : "Jij herstelde agenda {calendar}",
    "You shared calendar {calendar} as public link" : "Je deelde de agenda {calendar} als openbare link",
    "You removed public link for calendar {calendar}" : "Je verwijderde de openbare link voor de agenda {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} deelde agenda {calendar} met je",
    "You shared calendar {calendar} with {user}" : "Je deelde agenda {calendar} met {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} deelde agenda {calendar} met {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} is gestop de agenda {calendar} met je te delen",
    "You unshared calendar {calendar} from {user}" : "Je stopte met delen agenda {calendar} van {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} stopte met delen agenda {calendar} van {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} stopte het delen van agenda {calendar} van zichzelf",
    "You shared calendar {calendar} with group {group}" : "Je deelde agenda {calendar} met groep {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} deelde agenda {calendar} met groep {group}",
    "You unshared calendar {calendar} from group {group}" : "Je stopte het delen van agenda {calendar} van groep {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} stopte het delen van agenda {calendar} met groep {group}",
    "Untitled event" : "Afspraken zonder naam",
    "{actor} created event {event} in calendar {calendar}" : "{actor} creëerde afspraak {event} in agenda {calendar}",
    "You created event {event} in calendar {calendar}" : "Je creëerde afspraak {event} in agenda {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} verwijderde afspraak {event} uit agenda {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Je verwijderde afspraak {event} uit agenda {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} heeft afspraak {event} in agenda {calendar} bijgewerkt",
    "You updated event {event} in calendar {calendar}" : "Je hebt afspraak {event} in agenda {calendar} bijgewerkt",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} herstelde afspraak {event} in agenda {calendar}",
    "You restored event {event} of calendar {calendar}" : "Je herstelde afspraak {event} in agenda {calendar}",
    "Busy" : "Bezig",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} voegde de taak {todo} to aan de lijst {calendar}",
    "You created to-do {todo} in list {calendar}" : "Je voegde de taak {todo} toe aan de lijst {calendar}",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} verwijderde de taak {todo} van de lijst {calendar}",
    "You deleted to-do {todo} from list {calendar}" : "Jij verwijderde de taak {todo} van de lijst {calendar}",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor} paste de taak {todo} in de lijst {calendar} aan",
    "You updated to-do {todo} in list {calendar}" : "Jij paste de taak {todo} in de lijst {calendar} aan",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor} voltooide de taak {todo} in de lijst {calendar}",
    "You solved to-do {todo} in list {calendar}" : "Jij voltooide de taak {todo} in de lijst {calendar}",
    "Calendar, contacts and tasks" : "Agenda, contactpersonen en taken",
    "A <strong>calendar</strong> was modified" : "Een <strong>agenda</strong> is aangepast",
    "A calendar <strong>event</strong> was modified" : "Een agenda <strong>gebeurtenis</strong> is aangepast",
    "Contact birthdays" : "Verjaardagen",
    "Death of %s" : "Sterfdatum van %s",
    "Calendar:" : "Agenda",
    "Date:" : "Datum",
    "Where:" : "Waar:",
    "Description:" : "Omschrijving:",
    "_%n year_::_%n years_" : ["%n jaar","%n jaar"],
    "_%n month_::_%n months_" : ["%n maand","%n maanden"],
    "_%n day_::_%n days_" : ["%n dag","%n dagen"],
    "_%n hour_::_%n hours_" : ["%n uur","%n uur"],
    "_%n minute_::_%n minutes_" : ["%n minuut","%n minuten"],
    "%s (in %s)" : "%s (in %s)",
    "%s (%s ago)" : "%s (%s geleden)",
    "Calendar: %s" : "Agenda: %s",
    "Date: %s" : "Datum: %s",
    "Description: %s" : "Beschrijving: %s",
    "Where: %s" : "Waar: %s",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Cancelled: %1$s" : "Geannuleerd: %1$s",
    "Invitation canceled" : "Uitnodiging geannuleerd",
    "Re: %1$s" : "Re: %1$s",
    "Invitation updated" : "Uitnodiging bijgewerkt",
    "Invitation: %1$s" : "Uitnodiging: %1$s",
    "Invitation" : "Uitnodiging",
    "Title:" : "Titel:",
    "Time:" : "Tijd:",
    "Location:" : "Locatie:",
    "Link:" : "Link:",
    "Organizer:" : "Organisator:",
    "Attendees:" : "Deelnemers:",
    "Accept" : "Accepteren",
    "Decline" : "Afwijzen",
    "More options …" : "Meer opties …",
    "More options at %s" : "Meer opties op %s",
    "Contacts" : "Contactpersonen",
    "{actor} created address book {addressbook}" : "{actor} creëerde adresboek {addressbook}",
    "You created address book {addressbook}" : "Je creëerde adresboek  {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} verwijdede adresboek {addressbook}",
    "You deleted address book {addressbook}" : "Je verwijderde adresboek  {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} wijzigde adresboek {addressbook}",
    "You updated address book {addressbook}" : "Je wijzigde adresboek  {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} deelde adresboek {addressbook} met jou",
    "You shared address book {addressbook} with {user}" : "Jij deelde adresboek {addressbook} met {user}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} deelde adresboek {addressbook} met {user}",
    "{actor} unshared address book {addressbook} from you" : "{actor} stopte met delen adresboek {addressbook} van jou",
    "You unshared address book {addressbook} from {user}" : "Je stopte met delen adresboek {addressbook} van {user}",
    "{actor} unshared address book {addressbook} from {user}" : " stopte met delen adresboek {addressbook} van {user}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} stopte het delen van het adresboek {addressbook} van zichzelf",
    "You shared address book {addressbook} with group {group}" : "Je deelde adresboek {addressbook } met groep {group}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} deelde adresboek {addressbook} met groep {group}",
    "You unshared address book {addressbook} from group {group}" : "Je stopte het delen van adresboek {addressbook} van groep {group}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} stopte het delen van adresboek {addressbook} van groep {group}",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} creëerde contact {card} in adresboek {addressbook}",
    "You created contact {card} in address book {addressbook}" : "Je creëerde contact {card} in adresboek {addressbook}",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} verwijderde contact {card} uit adresboek {addressbook}",
    "You deleted contact {card} from address book {addressbook}" : "Je verwijderde contact {card} uit adresboek {addressbook}",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} wijzigde contact {card} in adresboek {addressbook}",
    "You updated contact {card} in address book {addressbook}" : "Je wijzigde contact {card} in adresboek {addressbook}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "Een <strong>contact</strong> uit adresboek </strong> is gewijzigd",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Could not open file" : "Kan het bestand niet openen",
    "Failed to open file: %1$s" : "Kon het bestand %1$s niet openen",
    "System is in maintenance mode." : "Systeem in onderhoudsmodus.",
    "Upgrade needed" : "Upgrade vereist",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Je %s moet worden geconfigureerd voor gebruik van HTTPS om CalDAV en CardDAV met iOS/macOS te kunnen gebruiken.",
    "Configures a CalDAV account" : "Configureert een CalDAV account",
    "Configures a CardDAV account" : "Configureert een CardDAV account",
    "Events" : "Evenementen",
    "Tasks" : "Taken",
    "Untitled task" : "Taak zonder titel",
    "Completed on %s" : "Voltooid op %s",
    "Due on %s by %s" : "Verwacht op %s door %s",
    "Due on %s" : "Verwacht op %s",
    "Contacts and groups" : "Contactpersonen en groepen",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "WebDAV eindpunt",
    "Availability" : "Beschikbaarheid",
    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Als je je werkuren instelt kunnen andere gebruikers zien wanneer je niet beschikbaar bent als ze een meeting willen plannen.",
    "Time zone:" : "Tijdzone:",
    "to" : "aan",
    "Delete slot" : "Verwijder slot",
    "No working hours set" : "Geen werkuren ingesteld",
    "Add slot" : "Voeg slot toe",
    "Monday" : "maandag",
    "Tuesday" : "dinsdag",
    "Wednesday" : "woensdag",
    "Thursday" : "donderdag",
    "Friday" : "vrijdag",
    "Saturday" : "zaterdag",
    "Sunday" : "zondag",
    "Save" : "Opslaan",
    "Failed to load availability" : "Kon beschikbaarheid niet laden",
    "Calendar server" : "Agendaserver",
    "Send invitations to attendees" : "Verzend uitnodigingen naar deelnemers",
    "Automatically generate a birthday calendar" : "Genereer verjaardagskalender automatisch",
    "Birthday calendars will be generated by a background job." : "Verjaardagkalenders zullen worden gegenereerd in een achtergrond taak.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Hierdoor zullen ze niet meteen beschikbaar zijn na het inschakelen maar zullen na een tijdje verschijnen.",
    "Send notifications for events" : "Versturen meldingen voor afspraken",
    "Notifications are sent via background jobs, so these must occur often enough." : "Meldingen worden via achtergrondtaken verstuurd, dus die moeten vaak genoeg plaatsvinden.",
    "Enable notifications for events via push" : "Inschakelen push-melding voor afspraken",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Installeer ook de {calendarappstoreopen}Agenda app{linkclose}, of {calendardocopen}verbind je desktop & mobiel voor synchronisatie ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Zorg ervoor dat je de {emailopen}de e-mailserver{linkclose} correct instelt.",
    "There was an error updating your attendance status." : "Er trad een fout op bij het bijwerken van je deelnamestatus.",
    "Please contact the organizer directly." : "Neem rechtstreeks contact op met de organisator.",
    "Are you accepting the invitation?" : "Neem je de uitnodiging aan?",
    "Tentative" : "Onder voorbehoud",
    "Number of guests" : "Aantal gasten",
    "Comment" : "Notitie",
    "Your attendance was updated successfully." : "Je deelname is succesvol bijgewerkt.",
    "Todos" : "Te doen",
    "{actor} created todo {todo} in list {calendar}" : "{actor} creëerde taak {todo} in lijst {calendar}",
    "You created todo {todo} in list {calendar}" : "Jij creëerde taak {todo} in lijst {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} heeft de taak {todo} uit lijst {calendar} verwijderd",
    "You deleted todo {todo} from list {calendar}" : "Je verwijderde taak {todo} uit lijst {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} heeft taak {todo} bijgewerkt in lijst {calendar}",
    "You updated todo {todo} in list {calendar}" : "Je hebt taak {todo} bijgewerkt in lijst {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} heeft taak {todo} in lijst {calendar} afgewerkt",
    "You solved todo {todo} in list {calendar}" : "Je hebt taak {todo} in lijst {calendar} afgewerkt",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} heropende taak {todo} in lijst {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Je heropende taak {todo} in lijst {calendar}",
    "A calendar <strong>todo</strong> was modified" : "Een agenda <strong>Te doen</strong> was aangepast"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-24.0.8.tgz: nextcloud/apps/dav/l10n/nl.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Agenda",
    "To-dos" : "Taken",
    "Personal" : "Persoonlijk",
    "{actor} created calendar {calendar}" : "{actor} creëerde agenda {calendar}",
    "You created calendar {calendar}" : "Jij creëerde agenda {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} verwijderde agenda {calendar}",
    "You deleted calendar {calendar}" : "Je verwijderde agenda {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} werkte agenda {calendar} bij",
    "You updated calendar {calendar}" : "Je werkte agenda {calendar} bij",
    "{actor} restored calendar {calendar}" : "{actor} herstelde agenda {calendar}",
    "You restored calendar {calendar}" : "Jij herstelde agenda {calendar}",
    "You shared calendar {calendar} as public link" : "Je deelde de agenda {calendar} als openbare link",
    "You removed public link for calendar {calendar}" : "Je verwijderde de openbare link voor de agenda {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} deelde agenda {calendar} met je",
    "You shared calendar {calendar} with {user}" : "Je deelde agenda {calendar} met {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} deelde agenda {calendar} met {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} is gestop de agenda {calendar} met je te delen",
    "You unshared calendar {calendar} from {user}" : "Je stopte met delen agenda {calendar} van {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} stopte met delen agenda {calendar} van {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} stopte het delen van agenda {calendar} van zichzelf",
    "You shared calendar {calendar} with group {group}" : "Je deelde agenda {calendar} met groep {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} deelde agenda {calendar} met groep {group}",
    "You unshared calendar {calendar} from group {group}" : "Je stopte het delen van agenda {calendar} van groep {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} stopte het delen van agenda {calendar} met groep {group}",
    "Untitled event" : "Afspraken zonder naam",
    "{actor} created event {event} in calendar {calendar}" : "{actor} creëerde afspraak {event} in agenda {calendar}",
    "You created event {event} in calendar {calendar}" : "Je creëerde afspraak {event} in agenda {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} verwijderde afspraak {event} uit agenda {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Je verwijderde afspraak {event} uit agenda {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} heeft afspraak {event} in agenda {calendar} bijgewerkt",
    "You updated event {event} in calendar {calendar}" : "Je hebt afspraak {event} in agenda {calendar} bijgewerkt",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} herstelde afspraak {event} in agenda {calendar}",
    "You restored event {event} of calendar {calendar}" : "Je herstelde afspraak {event} in agenda {calendar}",
    "Busy" : "Bezig",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} voegde de taak {todo} to aan de lijst {calendar}",
    "You created to-do {todo} in list {calendar}" : "Je voegde de taak {todo} toe aan de lijst {calendar}",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} verwijderde de taak {todo} van de lijst {calendar}",
    "You deleted to-do {todo} from list {calendar}" : "Jij verwijderde de taak {todo} van de lijst {calendar}",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor} paste de taak {todo} in de lijst {calendar} aan",
    "You updated to-do {todo} in list {calendar}" : "Jij paste de taak {todo} in de lijst {calendar} aan",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor} voltooide de taak {todo} in de lijst {calendar}",
    "You solved to-do {todo} in list {calendar}" : "Jij voltooide de taak {todo} in de lijst {calendar}",
    "Calendar, contacts and tasks" : "Agenda, contactpersonen en taken",
    "A <strong>calendar</strong> was modified" : "Een <strong>agenda</strong> is aangepast",
    "A calendar <strong>event</strong> was modified" : "Een agenda <strong>gebeurtenis</strong> is aangepast",
    "Contact birthdays" : "Verjaardagen",
    "Death of %s" : "Sterfdatum van %s",
    "Calendar:" : "Agenda",
    "Date:" : "Datum",
    "Where:" : "Waar:",
    "Description:" : "Omschrijving:",
    "_%n year_::_%n years_" : ["%n jaar","%n jaar"],
    "_%n month_::_%n months_" : ["%n maand","%n maanden"],
    "_%n day_::_%n days_" : ["%n dag","%n dagen"],
    "_%n hour_::_%n hours_" : ["%n uur","%n uur"],
    "_%n minute_::_%n minutes_" : ["%n minuut","%n minuten"],
    "%s (in %s)" : "%s (in %s)",
    "%s (%s ago)" : "%s (%s geleden)",
    "Calendar: %s" : "Agenda: %s",
    "Date: %s" : "Datum: %s",
    "Description: %s" : "Beschrijving: %s",
    "Where: %s" : "Waar: %s",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Cancelled: %1$s" : "Geannuleerd: %1$s",
    "Invitation canceled" : "Uitnodiging geannuleerd",
    "Re: %1$s" : "Re: %1$s",
    "Invitation updated" : "Uitnodiging bijgewerkt",
    "Invitation: %1$s" : "Uitnodiging: %1$s",
    "Invitation" : "Uitnodiging",
    "Title:" : "Titel:",
    "Time:" : "Tijd:",
    "Location:" : "Locatie:",
    "Link:" : "Link:",
    "Organizer:" : "Organisator:",
    "Attendees:" : "Deelnemers:",
    "Accept" : "Accepteren",
    "Decline" : "Afwijzen",
    "More options …" : "Meer opties …",
    "More options at %s" : "Meer opties op %s",
    "Contacts" : "Contactpersonen",
    "{actor} created address book {addressbook}" : "{actor} creëerde adresboek {addressbook}",
    "You created address book {addressbook}" : "Je creëerde adresboek  {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} verwijdede adresboek {addressbook}",
    "You deleted address book {addressbook}" : "Je verwijderde adresboek  {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} wijzigde adresboek {addressbook}",
    "You updated address book {addressbook}" : "Je wijzigde adresboek  {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} deelde adresboek {addressbook} met jou",
    "You shared address book {addressbook} with {user}" : "Jij deelde adresboek {addressbook} met {user}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} deelde adresboek {addressbook} met {user}",
    "{actor} unshared address book {addressbook} from you" : "{actor} stopte met delen adresboek {addressbook} van jou",
    "You unshared address book {addressbook} from {user}" : "Je stopte met delen adresboek {addressbook} van {user}",
    "{actor} unshared address book {addressbook} from {user}" : " stopte met delen adresboek {addressbook} van {user}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} stopte het delen van het adresboek {addressbook} van zichzelf",
    "You shared address book {addressbook} with group {group}" : "Je deelde adresboek {addressbook } met groep {group}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} deelde adresboek {addressbook} met groep {group}",
    "You unshared address book {addressbook} from group {group}" : "Je stopte het delen van adresboek {addressbook} van groep {group}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} stopte het delen van adresboek {addressbook} van groep {group}",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} creëerde contact {card} in adresboek {addressbook}",
    "You created contact {card} in address book {addressbook}" : "Je creëerde contact {card} in adresboek {addressbook}",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} verwijderde contact {card} uit adresboek {addressbook}",
    "You deleted contact {card} from address book {addressbook}" : "Je verwijderde contact {card} uit adresboek {addressbook}",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} wijzigde contact {card} in adresboek {addressbook}",
    "You updated contact {card} in address book {addressbook}" : "Je wijzigde contact {card} in adresboek {addressbook}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "Een <strong>contact</strong> uit adresboek </strong> is gewijzigd",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "Verwachte bestandsgrootte van %1$s maar gelezen (van Nextcloud-client) en geschreven (naar Nextcloud-opslag) %2$s. Dit kan een netwerkprobleem zijn aan de verzendende kant of een probleem met het schrijven naar de opslag aan de serverkant.",
    "Could not rename part file to final file, canceled by hook" : "Kon bestandsdeel niet hernoemen naar definitief bestand, geannuleerd door hook",
    "Could not rename part file to final file" : "Kon bestandsdeel niet hernoemen naar definitief bestand",
    "Failed to check file size: %1$s" : "Kon bestandsomvang niet controleren: %1$s",
    "Could not open file" : "Kan het bestand niet openen",
    "Encryption not ready: %1$s" : "Versleuteling niet gereed: %1$s",
    "Failed to open file: %1$s" : "Kon het bestand %1$s niet openen",
    "Failed to unlink: %1$s" : "Kon link niet verwijderen: %1$s",
    "Invalid chunk name" : "Ongeldige chunknaam",
    "Could not rename part file assembled from chunks" : "Kon een bestandsdeel dat uit chunks is samengesteld niet hernoemen",
    "Failed to write file contents: %1$s" : "Kon bestandsinhoud niet wegschrijven: %1$s",
    "File not found: %1$s" : "Bestand niet gevonden: %1$s",
    "System is in maintenance mode." : "Systeem in onderhoudsmodus.",
    "Upgrade needed" : "Upgrade vereist",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Je %s moet worden geconfigureerd voor gebruik van HTTPS om CalDAV en CardDAV met iOS/macOS te kunnen gebruiken.",
    "Configures a CalDAV account" : "Configureert een CalDAV account",
    "Configures a CardDAV account" : "Configureert een CardDAV account",
    "Events" : "Evenementen",
    "Tasks" : "Taken",
    "Untitled task" : "Taak zonder titel",
    "Completed on %s" : "Voltooid op %s",
    "Due on %s by %s" : "Verwacht op %s door %s",
    "Due on %s" : "Verwacht op %s",
    "Contacts and groups" : "Contactpersonen en groepen",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "WebDAV eindpunt",
    "Availability" : "Beschikbaarheid",
    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Als je je werkuren instelt kunnen andere gebruikers zien wanneer je niet beschikbaar bent als ze een meeting willen plannen.",
    "Time zone:" : "Tijdzone:",
    "to" : "aan",
    "Delete slot" : "Verwijder slot",
    "No working hours set" : "Geen werkuren ingesteld",
    "Add slot" : "Voeg slot toe",
    "Monday" : "maandag",
    "Tuesday" : "dinsdag",
    "Wednesday" : "woensdag",
    "Thursday" : "donderdag",
    "Friday" : "vrijdag",
    "Saturday" : "zaterdag",
    "Sunday" : "zondag",
    "Save" : "Opslaan",
    "Failed to load availability" : "Kon beschikbaarheid niet laden",
    "Calendar server" : "Agendaserver",
    "Send invitations to attendees" : "Verzend uitnodigingen naar deelnemers",
    "Automatically generate a birthday calendar" : "Genereer verjaardagskalender automatisch",
    "Birthday calendars will be generated by a background job." : "Verjaardagkalenders zullen worden gegenereerd in een achtergrond taak.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Hierdoor zullen ze niet meteen beschikbaar zijn na het inschakelen maar zullen na een tijdje verschijnen.",
    "Send notifications for events" : "Versturen meldingen voor afspraken",
    "Notifications are sent via background jobs, so these must occur often enough." : "Meldingen worden via achtergrondtaken verstuurd, dus die moeten vaak genoeg plaatsvinden.",
    "Enable notifications for events via push" : "Inschakelen push-melding voor afspraken",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Installeer ook de {calendarappstoreopen}Agenda app{linkclose}, of {calendardocopen}verbind je desktop & mobiel voor synchronisatie ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Zorg ervoor dat je de {emailopen}de e-mailserver{linkclose} correct instelt.",
    "There was an error updating your attendance status." : "Er trad een fout op bij het bijwerken van je deelnamestatus.",
    "Please contact the organizer directly." : "Neem rechtstreeks contact op met de organisator.",
    "Are you accepting the invitation?" : "Neem je de uitnodiging aan?",
    "Tentative" : "Onder voorbehoud",
    "Number of guests" : "Aantal gasten",
    "Comment" : "Notitie",
    "Your attendance was updated successfully." : "Je deelname is succesvol bijgewerkt.",
    "Todos" : "Te doen",
    "{actor} created todo {todo} in list {calendar}" : "{actor} creëerde taak {todo} in lijst {calendar}",
    "You created todo {todo} in list {calendar}" : "Jij creëerde taak {todo} in lijst {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} heeft de taak {todo} uit lijst {calendar} verwijderd",
    "You deleted todo {todo} from list {calendar}" : "Je verwijderde taak {todo} uit lijst {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} heeft taak {todo} bijgewerkt in lijst {calendar}",
    "You updated todo {todo} in list {calendar}" : "Je hebt taak {todo} bijgewerkt in lijst {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} heeft taak {todo} in lijst {calendar} afgewerkt",
    "You solved todo {todo} in list {calendar}" : "Je hebt taak {todo} in lijst {calendar} afgewerkt",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} heropende taak {todo} in lijst {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Je heropende taak {todo} in lijst {calendar}",
    "A calendar <strong>todo</strong> was modified" : "Een agenda <strong>Te doen</strong> was aangepast"
},
"nplurals=2; plural=(n != 1);");
